@@ -30,8 +30,8 @@ from .buildsystem import NoBuildToolsFound, detect_buildsystems
 from .resolver import (
     auto_resolver,
     native_resolvers,
+    UnsatisfiedRequirements,
 )
-from .resolver.apt import AptResolver
 
 
 def display_explain_commands(commands):
@@ -165,6 +165,7 @@ def main():  # noqa: C901
             args.explain = True
 
         if args.resolve == "apt":
+            from .resolver.apt import AptResolver
             resolver = AptResolver.from_session(session)
         elif args.resolve == "native":
             resolver = native_resolvers(session, user_local=args.user)
@@ -187,6 +188,11 @@ def main():  # noqa: C901
                         install_necessary_declared_requirements(
                             session, resolver, fixers, bss, stages, explain=args.explain
                         )
+                    except UnsatisfiedRequirements as e:
+                        logging.info('Unable to install declared dependencies:')
+                        for req in e.requirements:
+                            logging.info(' * %s', req)
+                        return 1
                     except ExplainInstall as e:
                         display_explain_commands(e.commands)
                         return 1
