@@ -17,7 +17,7 @@
 
 from functools import partial
 import logging
-from typing import List, Tuple, Callable, Any
+from typing import List, Tuple, Callable, Any, Optional
 
 from buildlog_consultant import Problem
 from buildlog_consultant.common import (
@@ -44,14 +44,17 @@ class BuildFixer(object):
         return self._fix(problem, phase)
 
 
-def run_detecting_problems(session: Session, args: List[str], **kwargs):
+def run_detecting_problems(session: Session, args: List[str], check_success=None, **kwargs):
+    if check_success is None:
+        def check_success(retcode, contents):
+            return (retcode == 0)
     try:
         retcode, contents = run_with_tee(session, args, **kwargs)
     except FileNotFoundError:
         error = MissingCommand(args[0])
         retcode = 1
     else:
-        if retcode == 0:
+        if check_success(retcode, contents):
             return contents
         lines = "".join(contents).splitlines(False)
         match, error = find_build_failure_description(lines)
@@ -104,8 +107,10 @@ def iterate_with_build_fixers(fixers: List[BuildFixer], cb: Callable[[], Any]):
 
 
 def run_with_build_fixers(
-    session: Session, args: List[str], fixers: List[BuildFixer], **kwargs
+    session: Session, args: List[str], fixers: Optional[List[BuildFixer]], **kwargs
 ):
+    if fixers is None:
+        fixers = []
     return iterate_with_build_fixers(
         fixers, partial(run_detecting_problems, session, args, **kwargs)
     )
